| effect | R Documentation |
Calculates cumulative or sub-group treatment effects
effect(x, cumu = TRUE, period = NULL, id = NULL, plot = FALSE)
x |
a |
cumu |
a logical flag indicating whether to calculate cumulative effects or not. |
id |
a string vector speicfying a sub-group of treated units that treatment effects are to be averaged on. |
period |
a two-element numeric vector specifying the range of term during which treatment effects are to be accumulated. If left blank, atts at all post-treatment periods will be calculated. |
plot |
a logical flag indicating whether to plot the cumulative effects. |
catt |
esimated (cumulative) atts. |
est.catt |
uncertainty estimates for |
Yiqing Xu <yiqingxu@stanfprd.edu>, Stanford University
Yiqing Xu. 2017. "Generalized Synthetic Control Method: Causal Inference with Interactive Fixed Effects Models." Political Analysis, Vol. 25, Iss. 1, January 2017, pp. 57-76.
gsynth
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.